aboutsummaryrefslogtreecommitdiff
path: root/src/runtime/stack.go
diff options
context:
space:
mode:
Diffstat (limited to 'src/runtime/stack.go')
-rw-r--r--src/runtime/stack.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/runtime/stack.go b/src/runtime/stack.go
index 7e69d65fbb..4b647976f0 100644
--- a/src/runtime/stack.go
+++ b/src/runtime/stack.go
@@ -1212,14 +1212,14 @@ func isShrinkStackSafe(gp *g) bool {
return false
}
// We also can't copy the stack while tracing is enabled, and
// gp is in _Gwaiting solely to make itself available to the GC.
// In these cases, the G is actually executing on the system
// stack, and the execution tracer may want to take a stack trace
// of the G's stack. Note: it's safe to access gp.waitreason here.
// We're only checking if this is true if we took ownership of the
// G with the _Gscan bit. This prevents the goroutine from transitioning,
// which prevents gp.waitreason from changing.
- if traceEnabled() && readgstatus(gp)&^_Gscan == _Gwaiting && gp.waitreason.isWaitingForGC() {
+ if traceEnabled() && readgstatus(gp)&^_Gscan == _Gwaiting && gp.waitreason.isWaitingForSuspendG() {
return false
}
return true
@@ -1212,14 +1212,14 @@ func isShrinkStackSafe(gp *g) bool {
}
// We also can't copy the stack while tracing is enabled, and
- // gp is in _Gwaiting solely to make itself available to the GC.
+ // gp is in _Gwaiting solely to make itself available to suspendG.
// In these cases, the G is actually executing on the system
// stack, and the execution tracer may want to take a stack trace